aioamqp was originally created in early 2014 at Polyconseil.

AUTHORS are (and/or have been)::

    * Benoît Calvez
    * Thomas Recouvreux
    * Guillaume Gauvrit
    * Morgan Delahaye-Prat
    * Mathias Fröjdman

